@@ -17,6 +17,12 @@ const (
 
 // GSA represents overview satellite data.
 // http://aprs.gids.nl/nmea/#gsa
+// https://gpsd.gitlab.io/gpsd/NMEA.html#_gsa_gps_dop_and_active_satellites
+//
+// Format:             $--GSA,a,a,x,x,x,x,x,x,x,x,x,x,x,x,x,x,x.x,x.x,x.x*hh<CR><LF>
+// Format (NMEA 4.1+): $--GSA,a,a,x,x,x,x,x,x,x,x,x,x,x,x,x,x,x.x,x.x,x.x,x*hh<CR><LF>
+// Example: $GNGSA,A,3,80,71,73,79,69,,,,,,,,1.83,1.09,1.47*17
+// Example (NMEA 4.1+): $GNGSA,A,3,13,12,22,19,08,21,,,,,,,1.05,0.64,0.83,4*0B
 type GSA struct {
 	BaseSentence
 	Mode    string   // The selection mode.
@@ -25,6 +31,14 @@ type GSA struct {
 	PDOP    float64  // Dilution of precision.
 	HDOP    float64  // Horizontal dilution of precision.
 	VDOP    float64  // Vertical dilution of precision.
+	// SystemID is (GNSS) System ID (NMEA 4.1+)
+	// 1 - GPS
+	// 2 - GLONASS
+	// 3 - Galileo
+	// 4 - BeiDou
+	// 5 - QZSS
+	// 6 - NavID (IRNSS)
+	SystemID int64
 }
 
 // newGSA parses the GSA sentence into this struct.
@@ -46,5 +60,9 @@ func newGSA(s BaseSentence) (GSA, error) {
 	m.PDOP = p.Float64(14, "pdop")
 	m.HDOP = p.Float64(15, "hdop")
 	m.VDOP = p.Float64(16, "vdop")
+
+	if len(p.Fields) > 17 {
+		m.SystemID = p.Int64(17, "system ID")
+	}
 	return m, p.Err()
 }
