@@ -1,18 +1,32 @@
 package nmea
 
 const (
-	// TypeGSV type for GSV sentences
+	// TypeGSV type of GSV sentences for satellites in view
 	TypeGSV = "GSV"
 )
 
 // GSV represents the GPS Satellites in view
 // http://aprs.gids.nl/nmea/#glgsv
+// https://gpsd.gitlab.io/gpsd/NMEA.html#_gsv_satellites_in_view
+//
+// Format:              $--GSV,x,x,x,x,x,x,x,...*hh<CR><LF>
+// Format (NMEA 4.1+):  $--GSV,x,x,x,x,x,x,x,...,x*hh<CR><LF>
+// Example: $GPGSV,3,1,11,09,76,148,32,05,55,242,29,17,33,054,30,14,27,314,24*71
+// Example (NMEA 4.1+): $GAGSV,3,1,09,02,00,179,,04,09,321,,07,11,134,11,11,10,227,,7*7F
 type GSV struct {
 	BaseSentence
 	TotalMessages   int64     // Total number of messages of this type in this cycle
 	MessageNumber   int64     // Message number
 	NumberSVsInView int64     // Total number of SVs in view
 	Info            []GSVInfo // visible satellite info (0-4 of these)
+	// SystemID is (GNSS) System ID (NMEA 4.1+)
+	// 1 - GPS
+	// 2 - GLONASS
+	// 3 - Galileo
+	// 4 - BeiDou
+	// 5 - QZSS
+	// 6 - NavID (IRNSS)
+	SystemID int64
 }
 
 // GSVInfo represents information about a visible satellite
@@ -33,8 +47,9 @@ func newGSV(s BaseSentence) (GSV, error) {
 		MessageNumber:   p.Int64(1, "message number"),
 		NumberSVsInView: p.Int64(2, "number of SVs in view"),
 	}
-	for i := 0; i < 4; i++ {
-		if 5*i+4 > len(m.Fields) {
+	i := 0
+	for ; i < 4; i++ {
+		if 6+i*4 >= len(m.Fields) {
 			break
 		}
 		m.Info = append(m.Info, GSVInfo{
@@ -44,5 +59,9 @@ func newGSV(s BaseSentence) (GSV, error) {
 			SNR:         p.Int64(6+i*4, "SNR"),
 		})
 	}
+	idxSID := (6 + (i-1)*4) + 1
+	if len(p.Fields) == idxSID+1 {
+		m.SystemID = p.Int64(idxSID, "system ID")
+	}
 	return m, p.Err()
 }
