@@ -28,6 +28,16 @@ var (
 // ParserFunc callback used to parse specific sentence variants
 type ParserFunc func(BaseSentence) (Sentence, error)
 
+// NotSupportedError is returned when parsed sentence is not supported
+type NotSupportedError struct {
+	Prefix string
+}
+
+// Error returns error message
+func (p *NotSupportedError) Error() string {
+	return fmt.Sprintf("nmea: sentence prefix '%s' not supported", p.Prefix)
+}
+
 // Sentence interface for all NMEA sentence
 type Sentence interface {
 	fmt.Stringer
@@ -179,6 +189,34 @@ func Parse(raw string) (Sentence, error) {
 		switch s.Type {
 		case TypeRMC:
 			return newRMC(s)
+		case TypeAAM:
+			return newAAM(s)
+		case TypeALA:
+			return newALA(s)
+		case TypeAPB:
+			return newAPB(s)
+		case TypeBEC:
+			return newBEC(s)
+		case TypeBOD:
+			return newBOD(s)
+		case TypeBWC:
+			return newBWC(s)
+		case TypeBWR:
+			return newBWR(s)
+		case TypeBWW:
+			return newBWW(s)
+		case TypeDOR:
+			return newDOR(s)
+		case TypeDSC:
+			return newDSC(s)
+		case TypeDSE:
+			return newDSE(s)
+		case TypeDTM:
+			return newDTM(s)
+		case TypeEVE:
+			return newEVE(s)
+		case TypeFIR:
+			return newFIR(s)
 		case TypeGGA:
 			return newGGA(s)
 		case TypeGSA:
@@ -191,32 +229,84 @@ func Parse(raw string) (Sentence, error) {
 			return newZDA(s)
 		case TypePGRME:
 			return newPGRME(s)
+		case TypePHTRO:
+			return newPHTRO(s)
+		case TypePRDID:
+			return newPRDID(s)
+		case TypePSONCMS:
+			return newPSONCMS(s)
 		case TypeGSV:
 			return newGSV(s)
+		case TypeHDG:
+			return newHDG(s)
 		case TypeHDT:
 			return newHDT(s)
+		case TypeHDM:
+			return newHDM(s)
+		case TypeHSC:
+			return newHSC(s)
 		case TypeGNS:
 			return newGNS(s)
 		case TypeTHS:
 			return newTHS(s)
+		case TypeTLL:
+			return newTLL(s)
+		case TypeTTM:
+			return newTTM(s)
+		case TypeTXT:
+			return newTXT(s)
 		case TypeWPL:
 			return newWPL(s)
+		case TypeRMB:
+			return newRMB(s)
+		case TypeRPM:
+			return newRPM(s)
+		case TypeRSA:
+			return newRSA(s)
+		case TypeRSD:
+			return newRSD(s)
 		case TypeRTE:
 			return newRTE(s)
+		case TypeROT:
+			return newROT(s)
+		case TypeVBW:
+			return newVBW(s)
+		case TypeVDR:
+			return newVDR(s)
 		case TypeVHW:
 			return newVHW(s)
+		case TypeVPW:
+			return newVPW(s)
+		case TypeVLW:
+			return newVLW(s)
+		case TypeVWR:
+			return newVWR(s)
+		case TypeVWT:
+			return newVWT(s)
 		case TypeDPT:
 			return newDPT(s)
 		case TypeDBT:
 			return newDBT(s)
+		case TypeDBK:
+			return newDBK(s)
 		case TypeDBS:
 			return newDBS(s)
 		case TypeMDA:
 			return newMDA(s)
+		case TypeMTA:
+			return newMTA(s)
+		case TypeMTW:
+			return newMTW(s)
 		case TypeMWD:
 			return newMWD(s)
 		case TypeMWV:
 			return newMWV(s)
+		case TypeOSD:
+			return newOSD(s)
+		case TypeXDR:
+			return newXDR(s)
+		case TypeXTE:
+			return newXTE(s)
 		}
 	}
 	if strings.HasPrefix(s.Raw, SentenceStartEncapsulated) {
@@ -225,5 +315,5 @@ func Parse(raw string) (Sentence, error) {
 			return newVDMVDO(s)
 		}
 	}
-	return nil, fmt.Errorf("nmea: sentence prefix '%s' not supported", s.Prefix())
+	return nil, &NotSupportedError{Prefix: s.Prefix()}
 }
